=============
MolSystem
=============


.. image:: https://img.shields.io/travis/molssi-seamm/molsystem.svg
           :target: https://travis-ci.org/molssi-seamm/molsystem
	   :alt: Build Status

.. image:: https://codecov.io/gh/molssi-seamm/molsystem/branch/master/graph/badge.svg
	   :target: https://codecov.io/gh/molssi-seamm/molsystem
	   :alt: Code Coverage

.. image:: https://img.shields.io/lgtm/grade/python/g/molssi-seamm/molsystem.svg?logo=lgtm&logoWidth=18
	   :target: https://lgtm.com/projects/g/molssi-seamm/molsystem/context:python
	   :alt: Code Quality

.. image:: https://readthedocs.org/projects/molsystem/badge/?version=latest
           :target: https://molsystem.readthedocs.io/en/latest/?badge=latest
	   :alt: Documentation Status

.. image:: https://pyup.io/repos/github/molssi-seamm/molsystem/shield.svg
	   :target: https://pyup.io/repos/github/molssi-seamm/molsystem/
	   :alt: Updates for Dependencies

.. image:: https://img.shields.io/pypi/v/molsystem.svg
           :target: https://pypi.python.org/pypi/molsystem
	   :alt: PyPi VERSION

Molsystem provides a general class for handling molecular and periodic systems


* Free software: GNU Lesser General Public License v3+
* Documentation: https://molsystem.readthedocs.io.


Features
--------

* Complete the initial version!

  * Remove the coordinates from the Atoms class and allow for multiple
    sets of coordinates -- conformers, trajectories, etc.
  * Provide a concept of the 'current' system

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage


Developed by the Molecular Sciences Software Institute (MolSSI_),
which receives funding from the `National Science Foundation`_ under
award OAC-1547580 and CHE-2136142.

.. _MolSSI: https://www.molssi.org
.. _`National Science Foundation`: https://www.nsf.gov
